@@ -229,7 +229,7 @@ lme.list = list(
   title = "lme()",
   help = "lme",
   type = "text",                      # either text or graphic
-  variableType = "lme",
+  variableType = "lmer",
   assignto = TRUE,
   action = list(
     beginning = "require(nlme);lme(",
